@@ -38,14 +38,15 @@
 
 #include <KAboutData>
 #include <KCrash>
-
-#include "kfourinline_debug.h"
+#include <Kdelibs4ConfigMigrator>
 #include <KLocalizedString>
+
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QCommandLineOption>
-#include <Kdelibs4ConfigMigrator>
+
 #include "kwin4.h"
+#include "kfourinline_debug.h"
 
 #define KWIN4_VERSION "v1.41"
 
@@ -83,8 +84,6 @@ int main(int argc, char *argv[])
     QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
     KCrash::initialize();
-    parser.addVersionOption();
-    parser.addHelpOption();
   parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("d") << QStringLiteral("debug"), i18n("Enter debug level"), QStringLiteral("level")));
   parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("skipintro"), i18n("Skip intro animation")));
   parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("demo"), i18n("Run game in demo (autoplay) mode")));
